@@ -49,19 +49,38 @@ plot.grain <- function(x, type, ...){
   }
 }
 
+iplot.grain <- function(x,type, ...){
+  #.primiplot(x$dag)
+
+  if (missing(type)){
+    if (x$isCompiled){
+      .primiplot(x$ug)
+    } else {
+      if ("pot-grain" %in% class(x)){
+        .primiplot(x$ug)
+      } else {
+        .primiplot(x$dag)
+      }
+    }
+  } else {
+    zz <- x[[type]]
+    if (!is.null(zz))
+      .primiplot(zz)
+    else
+      cat("Slot", type, "does not exist \n") 
+  }
+}
+
+.primiplot <- function(grp){
+  ig <- igraph.from.graphNEL(grp)
+  V(ig)$label <- V(ig)$name
+  V(ig)$size  <- 40
+  ig$cex   <-  4
+  ig$layout   <- layout.graphopt
+  plot(ig)
+}
 
 
-## .plot.graphsh <- function(graph){
-
-##   if (!require("Rgraphviz")){
-##     cat("The Rgraphviz package (from Bioconductor) must be installed to display the models\n")
-##     return()
-##   }
-
-##   ###plot(as.graphNEL(graph))
-##   plot(graph)
-##   return(invisible(graph))
-## }
 
 ########################################################################
 
